From 0.6.0 to 0.7.0
===================

  ==================  =============================================
  Concerns            What happened
  ==================  =============================================
  pyaC                *New functionality*
                        - Formatted output of 2d matrices
                        - Numerical derivatives (diffCFD)
  pyasl               *New functionality*
                        - Cross-correlation algorithm (crosscorrRV)
                        - Finding extreme point by parabolic fit
                          (quadExtreme)
                        - Calculate decimal year (decimalYear)
                        - Gaussian instrumental broadening
                          (instrBroadGaussFast)
                        - Reading spectrum from fits file
                        - Distance module to distance conversion
                        - Position angle
  funcFit             *New functionality*
                        - Various bug fixes.
                        - Introduced external fitters
                        - Multicomponent two-dimensional Gaussian
                        - Conditional restrictions
  modelSuite          *New functionality*
                        - Rotational broadening profile
  ==================  =============================================